Learn R Programming

ttbbeer (version 1.1.0)

artificialcarbontax: The artificialcarbontax dataset

Description

This dataset contains a list of historical tax rates for artificial carbon per wine gallon from TTB.

Usage

artificialcarbontax

Arguments

Format

A data frame with 10 observations of 3 variables: