Learn R Programming

ttbbeer (version 1.1.0)

spirittax: The spirittax dataset

Description

This dataset contains a list of historical tax rates for distilled spirits per proof gallon from TTB.

Usage

spirittax

Arguments

Format

A data frame with 15 observations of 3 variables: